#!/bin/bash

set -e # Abort on error.

declare -a _extra_modules
# Avoid Xcode
if [[ ${HOST} =~ .*darwin.* ]]; then
  PATH=${PREFIX}/bin/xc-avoidance:${PATH}
    _extra_modules+=(--enable)
    _extra_modules+=(QtMacExtras)
    extra_modules+=(--no-designer-plugin)
    extra_modules+=(--no-qml-plugin)
else
    _extra_modules+=(--enable)
    _extra_modules+=(QtX11Extras)
fi

# Dumb .. is this Qt or PyQt's fault? (or mine, more likely).
# The spec file could be bad, or PyQt could be missing the
# ability to set QMAKE_CXX
mkdir bin || true
pushd bin
  ln -s ${GXX} g++ || true
  ln -s ${GCC} gcc || true
popd
export PATH=${PWD}/bin:${PATH}

## Future:
#        --enable Qt3DAnimation \
#        --enable Qt3DCore \
#        --enable Qt3DExtras \
#        --enable Qt3DInput \
#        --enable Qt3DLogic \
#        --enable Qt3DRender \

sed -i '' -E "s|-L.*/_build_env|${PREFIX}|g" $PREFIX/lib/*.prl
sed -i '' -E "s|-L.*/_build_env|${PREFIX}|g" $PREFIX/lib/pkgconfig/*.pc || true
sed -i '' -E "s|\+= /.*/_build_env|\+= ${PREFIX}|g" $PREFIX/mkspecs/*.pri || true
sed -i '' -E "s|CROSS_COMPILE = /.*/_build_env|CROSS_COMPILE = ${BUILD_PREFIX}|g" $PREFIX/mkspecs/*.pri || true
sed -i '' -E "s|BUILD_PREFIX = /.*/_build_env|BUILD_PREFIX = ${BUILD_PREFIX}|g" $PREFIX/mkspecs/*.pri || true

sed -i '' -E "s|QMAKE_PRL_BUILD_DIR = /.*/work|QMAKE_PRL_BUILD_DIR = ${PREFIX}|g" lib/*.prl || true

# need to build a private copy of sip to avoid "module PyQt5.sip not found" error
echo -e "\n************** start building a private sip module **************\n"
#echo "PWD: ${SRC_DIR}"
cd sip
$PYTHON configure.py --sip-module PyQt5.sip
make -j${CPU_COUNT} # ${VERBOSE_AT}
make install
cd ../
echo -e "\n************************ built sip module ***********************\n"

## create alias for libGL.so
#ln -s ${PREFIX}/x86_64-conda_cos6-linux-gnu/sysroot/usr/lib64/libGL.so.1 \
#      ${PREFIX}/x86_64-conda_cos6-linux-gnu/sysroot/usr/lib64/libGL.so

## START BUILD
echo -e "\n************** start building PyQt5 **************\n"
cd pyqt5
# --enable QtDesigner 
$PYTHON configure.py \
        --verbose \
        --confirm-license \
        --assume-shared \
        --enable QtBluetooth \
        --enable QtCore \
        --enable QtDBus \
        --enable QtGui \
        --enable QtHelp \
        --enable QtLocation \
        --enable QtMultimedia \
        --enable QtMultimediaWidgets \
        --enable QtNetwork \
        --enable QtNfc \
        --enable QtOpenGL \
        --enable QtPositioning \
        --enable QtPrintSupport \
        --enable QtQml \
        --enable QtQuick \
        --enable QtQuickWidgets \
        --enable QtSensors \
        --enable QtSql \
        --enable QtSvg \
        --enable QtTest \
        --enable QtWebChannel \
        --enable QtWebSockets \
        --enable QtWidgets \
        --enable QtXml \
        --enable QtXmlPatterns \
        --pyuic5-interpreter=`which python` \
        "${_extra_modules[@]}" \
        -q ${PREFIX}/bin/qmake

make -j${CPU_COUNT} ${VERBOSE_AT}
make check
make install
cd ../
echo -e "\n******************* built PyQt5 ******************\n"

if [[ 1 == 0 ]]; then
# install PyQtWebEngine
echo -e "\n************** start building PyQtWebEngine **************\n"
cd pyqtwebengine
${PYTHON} configure.py
make -j${CPU_COUNT} ${VERBOSE_AT}
make install
cd ../
fi

echo -e "\n****************** built PyQtWebEngine *******************\n"

if [[ 1 == 1 ]]; then
# install PyQtCharts
echo -e "\n************** start building PyQtCharts **************\n"
cd pyqtcharts
${PYTHON} configure.py
make -j${CPU_COUNT} ${VERBOSE_AT}
make install
cd ../
fi

echo -e "\n****************** built PyQtCharts *******************\n"
